# Project name here
> Summary description here.


This file will become your README and also the index of your documentation.

## Install

`pip install cousie`

## How to use

Let's see this at work wooo:

```python
1+1
```




    2



```python
say_hello('Maral')
```




    'Hello Maral!'


